@@ -210,14 +210,18 @@ class LevelsHistogram(BasePlot):
         Args:
             item: item which was removed
         """
-        for _plot, items in list(self._tracked_items.items()):
-            if item in items:
+        replot = False
+        for _plot, items_dict in list(self._tracked_items.items()):
+            if item in items_dict:
                 try:
-                    self.del_item(item)
+                    self.del_item(items_dict[item])
+                    replot = True
                 except ValueError:
                     pass  # Histogram has not yet been created
-                items.pop(item)
+                items_dict.pop(item)
                 break
+        if replot:
+            self.replot()
 
     def active_item_changed(self, plot: BasePlot) -> None:
         """Active item changed callback
@@ -586,7 +590,7 @@ class ContrastAdjustment(PanelWidget):
             """Apply callback"""
             self.histogram.set_range(param.zmin, param.zmax)
 
-        param = RangeParam()
+        param = RangeParam(_("Set range"))
         zmin_0, zmax_0 = param.zmin, param.zmax = self.histogram.range.get_range()
         if param.edit(self, apply=apply_callback):
             apply_callback(param)
