@@ -20,12 +20,13 @@ from plotpy.coords import axes_to_canvas
 from plotpy.events import QtDragHandler, setup_standard_tool_filter
 from plotpy.interfaces import (
     IColormapImageItemType,
-    IStatsImageItemType,
+    IImageItemType,
     IVoiImageItemType,
 )
 from plotpy.items import (
     AnnotatedRectangle,
     EllipseShape,
+    ImageItem,
     MaskedImageItem,
     MaskedXYImageItem,
     RectangleShape,
@@ -33,6 +34,7 @@ from plotpy.items import (
     get_items_in_rectangle,
 )
 from plotpy.mathutils.colormap import ALL_COLORMAPS, build_icon_from_cmap_name, get_cmap
+from plotpy.plot import BasePlot
 from plotpy.tools.base import (
     CommandTool,
     DefaultToolbarID,
@@ -56,13 +58,45 @@ if TYPE_CHECKING:
     from plotpy.items.image.base import BaseImageItem
     from plotpy.items.shape.base import AbstractShape
     from plotpy.items.shape.polygon import PolygonShape
-    from plotpy.plot import BasePlot
     from plotpy.plot.manager import PlotManager
     from plotpy.plot.plotwidget import PlotOptions
     from plotpy.styles.image import BaseImageParam
     from plotpy.styles.shape import AnnotationParam
 
 
+def get_stats(
+    item: BaseImageItem,
+    x0: float,
+    y0: float,
+    x1: float,
+    y1: float,
+) -> str:
+    """Return formatted string with stats on image rectangular area
+    (output should be compatible with AnnotatedShape.get_infos)
+
+    Args:
+        item: image item
+        x0: X0
+        y0: Y0
+        x1: X1
+        y1: Y1
+    """
+    ix0, iy0, ix1, iy1 = item.get_closest_index_rect(x0, y0, x1, y1)
+    data = item.data[iy0:iy1, ix0:ix1]
+    p: BaseImageParam = item.param
+    return "<br>".join(
+        [
+            "%sx%s %s" % (item.data.shape[1], item.data.shape[0], str(item.data.dtype)),
+            "",
+            "%s ≤ x ≤ %s" % (p.xformat % x0, p.xformat % x1),
+            "%s ≤ y ≤ %s" % (p.yformat % y0, p.yformat % y1),
+            "%s ≤ z ≤ %s" % (p.zformat % data.min(), p.zformat % data.max()),
+            "‹z› = " + p.zformat % data.mean(),
+            "σ(z) = " + p.zformat % data.std(),
+        ]
+    )
+
+
 class ImageStatsRectangle(AnnotatedRectangle):
     """Rectangle used to display image statistics
 
@@ -72,8 +106,10 @@ class ImageStatsRectangle(AnnotatedRectangle):
         x2: X position of the second rectangle corner. Defaults to 0.
         y2: Y position of the second rectangle corner. Defaults to 0.
         annotationparam: _description_. Defaults to None.
-        show_surface: _description_. Defaults to False.
-        show_integral: _description_. Defaults to False.
+        stats_func: function to get statistics. Defaults to None.
+         (see :py:func:`get_stats` for signature and default implementation)
+        replace: True to replace stats (statistics are not added to the
+         base infos but replace them). Defaults to False.
     """
 
     shape: PolygonShape
@@ -85,15 +121,15 @@ class ImageStatsRectangle(AnnotatedRectangle):
         x2: float = 0.0,
         y2: float = 0.0,
         annotationparam: AnnotationParam | None = None,
-        show_surface=False,
-        show_integral=False,
+        stats_func: Callable[[BaseImageItem, float, float, float, float]] | None = None,
+        replace: bool = False,
     ):
         """_summary_"""
         super().__init__(x1, y1, x2, y2, annotationparam)
         self.image_item: BaseImageItem | None = None
         self.setIcon(get_icon("imagestats.png"))
-        self.show_surface = show_surface
-        self.show_integral = show_integral
+        self.stats_func = stats_func
+        self.replace_stats = replace
 
     def set_image_item(self, image_item: BaseImageItem) -> None:
         """Set image item to be used for statistics
@@ -102,6 +138,7 @@ class ImageStatsRectangle(AnnotatedRectangle):
             image_item: image item to be used for statistics
         """
         self.image_item = image_item
+        self.setTitle(self.image_item.title())
 
     # ----AnnotatedShape API-----------------------------------------------------
     def get_infos(self) -> str | None:
@@ -129,9 +166,16 @@ class ImageStatsRectangle(AnnotatedRectangle):
                 return _("No available data")
         else:
             return _("No available data")
-        return self.image_item.get_stats(
-            *self.get_rect(), self.show_surface, self.show_integral
-        )
+        x0, y0, x1, y1 = self.get_rect()
+        if self.replace_stats:
+            base_infos = ""
+        else:
+            base_infos = get_stats(self.image_item, x0, y0, x1, y1)
+        if self.stats_func is not None:
+            if base_infos:
+                base_infos += "<br>"
+            base_infos += self.stats_func(self.image_item, x0, y0, x1, y1)
+        return base_infos
 
 
 class ImageStatsTool(RectangularShapeTool):
@@ -148,8 +192,26 @@ class ImageStatsTool(RectangularShapeTool):
         title: tool title. Defaults to None.
         icon: tool icon filename. Defaults to None.
         tip: user tip to be displayed. Defaults to None.
-        show_surface: Flag to show surface. Defaults to False.
-        show_integral: Flag to show integral. Defaults to False.
+        stats_func: function to get statistics. Defaults to None.
+         (see :py:func:`get_stats` for signature and default implementation)
+        replace: True to replace stats (statistics are not added to the
+         base infos but replace them). Defaults to False.
+
+    .. note:: The stats_func function should return a formatted string with
+        statistics on the image rectangular area. The function signature should
+        be::
+
+            def stats_func(item, x0, y0, x1, y1):
+                return formatted_string
+
+        where item is the image item, x0, y0, x1, y1 are the rectangle coordinates
+        and formatted_string is the formatted string with statistics on the image
+        rectangular area.
+
+        Default implementation is the following:
+
+        .. literalinclude:: ../../../plotpy/tools/image.py
+           :pyobject: get_stats
 
     """
 
@@ -168,8 +230,8 @@ class ImageStatsTool(RectangularShapeTool):
         title: str | None = None,
         icon: str | None = None,
         tip: str | None = None,
-        show_surface: bool = False,
-        show_integral: bool = False,
+        stats_func: Callable[[BaseImageItem, float, float, float, float]] | None = None,
+        replace: bool = False,
     ) -> None:
         super().__init__(
             manager,
@@ -182,8 +244,24 @@ class ImageStatsTool(RectangularShapeTool):
             tip,
         )
         self._last_item = None
-        self.show_surface = show_surface
-        self.show_integral = show_integral
+        self.stats_func = stats_func
+        self.replace_stats = replace
+
+    def set_stats_func(
+        self,
+        stats_func: Callable[[BaseImageItem, float, float, float, float]],
+        replace: bool = False,
+    ) -> None:
+        """Set the function to get statistics
+
+        Args:
+            stats_func: function to get statistics
+             (see :py:func:`get_stats` for signature and default implementation)
+            replace: True to replace stats (statistics are not added to the base infos
+             but replace them). Defaults to False.
+        """
+        self.stats_func = stats_func
+        self.replace_stats = replace
 
     def get_last_item(self) -> BaseImageItem | None:
         """Last image item getter
@@ -196,8 +274,8 @@ class ImageStatsTool(RectangularShapeTool):
         return None
 
     def create_shape(self) -> tuple[ImageStatsRectangle, Literal[0], Literal[2]]:
-        """Returns a new ImageStatsRectangle instance with default x1, y1, x2, y2values
-        and current show_surface and show_integral values.
+        """Returns a new ImageStatsRectangle instance and the index of handles to
+        display.
 
         Returns:
             New ImageStatsRectangle instance
@@ -208,8 +286,8 @@ class ImageStatsTool(RectangularShapeTool):
                 0,
                 1,
                 1,
-                show_surface=self.show_surface,
-                show_integral=self.show_integral,
+                stats_func=self.stats_func,
+                replace=self.replace_stats,
             ),
             0,
             2,
@@ -222,7 +300,6 @@ class ImageStatsTool(RectangularShapeTool):
             shape: Shape to setup
         """
         super().setup_shape(shape)
-        shape.setTitle(_("Image statistics"))
         self.set_shape_style(shape)
         self.register_shape(shape, final=False)
 
@@ -258,7 +335,7 @@ class ImageStatsTool(RectangularShapeTool):
         Returns:
             Reference to the last image item associated with the tool
         """
-        items = plot.get_selected_items(item_type=IStatsImageItemType)
+        items = plot.get_selected_items(item_type=IImageItemType)
         if len(items) == 1:
             self._last_item = weakref.ref(items[0])
         return self.get_last_item()
@@ -274,15 +351,16 @@ class ImageStatsTool(RectangularShapeTool):
             self.action.setEnabled(item is not None)
 
 
-class ReverseYAxisTool(ToggleTool):
-    """Togglable tool to reverse y axis
+class BaseReverseAxisTool(ToggleTool):
+    """Base class for tools to reverse axes"""
 
-    Args:
-        manager: PlotManager Instance
-    """
+    TITLE = ""  # To be defined in subclasses
+    AXIS_ID = -1  # To be defined in subclasses
 
     def __init__(self, manager: PlotManager) -> None:
-        super().__init__(manager, _("Reverse Y axis"))
+        assert self.TITLE, "TITLE must be defined in subclasses"
+        assert self.AXIS_ID in BasePlot.AXIS_IDS, "Invalid AXIS_ID"
+        super().__init__(manager, self.TITLE)
 
     def activate_command(self, plot: BasePlot, checked: bool) -> None:
         """Triggers tool action.
@@ -291,8 +369,9 @@ class ReverseYAxisTool(ToggleTool):
             plot: Plot instance
             checked: True if tool is checked, False otherwise
         """
-        plot.set_axis_direction("left", checked)
+        plot.set_axis_direction(self.AXIS_ID, checked)
         plot.replot()
+        plot.SIG_AXIS_PARAMETERS_CHANGED.emit(self.AXIS_ID)
 
     def update_status(self, plot: BasePlot) -> None:
         """Update tool status if the plot type is not PlotType.CURVE.
@@ -301,7 +380,68 @@ class ReverseYAxisTool(ToggleTool):
             plot: Plot instance
         """
         if update_image_tool_status(self, plot):
-            self.action.setChecked(plot.get_axis_direction("left"))
+            self.action.setChecked(plot.get_axis_direction(self.AXIS_ID))
+
+
+class ReverseXAxisTool(BaseReverseAxisTool):
+    """Togglable tool to reverse X axis
+
+    Args:
+        manager: PlotManager Instance
+    """
+
+    TITLE = _("Reverse X axis")
+    AXIS_ID = BasePlot.X_BOTTOM
+
+
+class ReverseYAxisTool(BaseReverseAxisTool):
+    """Togglable tool to reverse Y axis
+
+    Args:
+        manager: PlotManager Instance
+    """
+
+    TITLE = _("Reverse Y axis")
+    AXIS_ID = BasePlot.Y_LEFT
+
+
+class ZAxisLogTool(ToggleTool):
+    """Patched tools.ToggleTool"""
+
+    def __init__(self, manager: PlotManager) -> None:
+        title = _("Base-10 logarithmic Z axis")
+        super().__init__(
+            manager,
+            title=title,
+            toolbar_id=DefaultToolbarID,
+            icon="zlog.svg",
+        )
+
+    def activate_command(self, plot: BasePlot, checked: bool) -> None:
+        """Reimplement tools.ToggleTool method"""
+        for item in self.get_supported_items(plot):
+            item.set_zaxis_log_state(not item.get_zaxis_log_state())
+        plot.replot()
+        self.update_status(plot)
+
+    def get_supported_items(self, plot: BasePlot) -> list[BaseImageItem]:
+        """Reimplement tools.ToggleTool method"""
+        items = [
+            item
+            for item in plot.get_items()
+            if isinstance(item, ImageItem)
+            and not item.is_empty()
+            and hasattr(item, "get_zaxis_log_state")
+        ]
+        if len(items) > 1:
+            items = [item for item in items if item in plot.get_selected_items()]
+        if items:
+            self.action.setChecked(items[0].get_zaxis_log_state())
+        return items
+
+    def update_status(self, plot: BasePlot) -> None:
+        """Reimplement tools.ToggleTool method"""
+        self.action.setEnabled(len(self.get_supported_items(plot)) > 0)
 
 
 class AspectRatioParam(DataSet):
